import request from "./request.js";

// 获取酒吧信息
export function getBarInfo() {
	return request({
		url: `/bar/barinfo/getBarInfo`,
		method: 'get',
	})
}

// 编辑酒吧信息
export function editBarInfo(data) {
	return request({
		url: `/bar/barinfo`,
		method: 'put',
		data
	})
}
// 我关注的品牌方活动列表
export function getFavoriteActivities(data) {
	return request({
		url: '/bar/brewery/getFavoriteActivities',
		method: 'get',
		data
	})
}
// 获取品牌方活动列表
export function getActivities(data) {
	return request({
		url: '/bar/brewery/getActivities',
		method: 'get',
		data
	})
}

// 获取营销活动详细信息
export function getActivityInfo(id) {
	return request({
		url: `/bar/brewery/getActivityInfo/${id}`,
		method: 'get',
	})
}

// 获取酒款详细信息
export function getBeerInfo(id) {
	return request({
		url: `/bar/brewery/getBeerInfo/${id}`,
		method: 'get',
	})

}

// 获取品牌方酒款列表
export function getBeerList(data) {
	return request({
		url: '/bar/brewery/getBeerList',
		method: 'get',
		data
	})
}

// 获取品牌方列表
export function getBreweries(data) {
	return request({
		url: '/bar/brewery/getBreweries',
		method: 'get',
		data
	})

}

// 获取单个品牌方活动列表
export function getBreweryActivities(data) {
	return request({
		url: `/bar/brewery/getBreweryActivities/${data.id}`,
		method: 'get',
		data: {
			pageNum: data.pageNum,
			pageSize: data.pageSize
		}
	})

}

// 获取单个品牌方酒款列表
export function getBreweryBeerList(data) {
	return request({
		url: `/bar/brewery/getBreweryBeerList/${data.id}`,
		method: 'get',
		data: {
			pageNum: data.pageNum,
			pageSize: data.pageSize
		}
	})

}

// 获取单个品牌方兑换商品列表
export function getBreweryGoodsList(data) {
	return request({
		url: `/bar/brewery/getBreweryGoodsList/${data.id}`,
		method: 'get',
		data: {
			pageNum: data.pageNum,
			pageSize: data.pageSize
		}
	})

}

// 获取品牌方详细信息
export function getBreweryInfo(id) {
	return request({
		url: `/bar/brewery/getBreweryInfo/${id}`,
		method: 'get'
	})

}

// 获取兑换商品详细信息
export function getGoodsInfo(id) {
	return request({
		url: `/bar/brewery/getGoodsInfo/${id}`,
		method: 'get'
	})

}

// 获取品牌方兑换商品列表
export function getGoodsList(data) {
	return request({
		url: '/bar/brewery/getGoodsList',
		method: 'get',
		data
	})

}


// 查询banner列表
export function getBannerList(data) {
	return request({
		url: '/bar/platform/banner/list',
		method: 'get',
		data
	})
}

// 获取我发布的酒评详细信息
export function getMyReviewInfo(beerId) {
	return request({
		url: `/bar/brewery/getMyReviewInfo/${beerId}`,
		method: 'get',
	})
}
// 获取酒评详细信息
export function getReviewInfo(id) {
	return request({
		url: `/bar/brewery/getReviewInfo/${id}`,
		method: 'get',
	})
}
// 获取酒评评分列表
export function getReviewScoreList(beerId) {
	return request({
		url: '/bar/brewery/getReviewScoreList?beerId=' + beerId,
		method: 'get',
	})
}
// 获取酒评列表
export function getReviewList(data) {
	return request({
		url: '/bar/brewery/getReviewList',
		method: 'get',
		data
	})
}

// 新增酒评
export function addReview(data) {
	return request({
		url: '/bar/beer/review/addReview',
		method: 'post',
		data
	})
}

// 收藏-酒款
export function favorBeer(data) {
	return request({
		url: '/bar/brewery/favorBeer',
		method: 'post',
		data
	})
}

// 收藏-品牌
export function favorBrewery(data) {
	return request({
		url: '/bar/brewery/favorBrewery',
		method: 'post',
		data
	})
}

// 点赞评论
export function likeReview(data) {
	return request({
		url: '/bar/beer/review/reviewLike',
		method: 'post',
		data
	})
}

// 核销二维码
export function consumeCode(data) {
	return request({
		url: '/bar/qrcode/consume',
		method: 'post',
		data
	})
}

// 查询二维码信息
export function getQrcodeInfo(data) {
	return request({
		url: '/bar/qrcode/checkout',
		method: 'post',
		data
	})
}

// 门店啤酒币余额
export function getStoreCoinBalance() {
	return request({
		url: `/bar/user/coinList`,
		method: 'get',
	})
}
// 特定品牌啤酒币余额
export function getBreweryCoinBalance(breweryId) {
	return request({
		url: `/bar/user/coinDetail?breweryId=${breweryId}`,
		method: 'get',
	})
}
// 查询我啤酒币变动记录
export function getCoinRecordList(data) {
	return request({
		url: '/bar/user/coinRecordList',
		method: 'get',
		data
	})
}


// 创建兑换订单
export function createOrder(data) {
	return request({
		url: '/bar/brewery/createOrder',
		method: 'post',
		data
	})
}
// 获取兑换订单
export function getOrderView(orderId) {
	return request({
		url: '/bar/brewery/orderView?orderId=' + orderId,
		method: 'get',
	})
}
// 获取酒单模版
export function getBillTemplateList() {
	return request({
		url: '/bar/bill/templateList',
		method: 'get',
	})
}
// 酒单模版详情
export function getTemplateDetail(templateId) {
	return request({
		url: '/bar/bill/templateDetail?templateId=' + templateId,
		method: 'get',
	})
}

// 保存导出记录
export function saveExportRecord(templateId) {
	return request({
		url: '/bar/bill/saveExportRecord?templateId=' + templateId,
		method: 'post'
	})
}


// 查询酒款收藏状态
export function getBeerFavorStatus(beerId) {
	return request({
		url: '/bar/user/favoriteBeerByBeerId?beerId=' + beerId,
		method: 'get',
	})
}
// 查询品牌收藏状态
export function getBreweryFavorStatus(breweryId) {
	return request({
		url: '/bar/user/favoriteBreweryByBreweryId?breweryId=' + breweryId,
		method: 'get',
	})
}

// 重新认证
export function reAuth(data) {
	return request({
		url: '/bar/barinfo/reAuth',
		method: 'post',
		data
		})
}


// 查询我的活动详情
export function getMyActivityDetail(activityId) {
	return request({
		url: '/bar/user/myActivityDetail?activityId=' + activityId,
		method: 'get',
	})
}